hyperspy\.external\.mpfit package
=================================

Submodules
----------

hyperspy\.external\.mpfit\.mpfit module
---------------------------------------

.. automodule:: hyperspy.external.mpfit.mpfit
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.external\.mpfit\.mpfitexpr module
-------------------------------------------

.. automodule:: hyperspy.external.mpfit.mpfitexpr
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.external\.mpfit\.test\_mpfit module
---------------------------------------------

.. automodule:: hyperspy.external.mpfit.test_mpfit
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hyperspy.external.mpfit
    :members:
    :undoc-members:
    :show-inheritance:
